# coincident

[![Actions Status][actions-badge]][actions-link]
[![Documentation Status][rtd-badge]][rtd-link]
[![Available on pypi][pypi-version]][pypi-link]

[![DOI](https://zenodo.org/badge/853370896.svg)](https://doi.org/10.5281/zenodo.14327521)

[![Open in GitHub Codespaces](https://github.com/codespaces/badge.svg)](https://codespaces.new/uw-cryo/coincident)

<!-- SPHINX-START -->

<!-- prettier-ignore-start -->
[actions-badge]:            https://github.com/uw-cryo/coincident/workflows/CI/badge.svg
[actions-link]:             https://github.com/uw-cryo/coincident/actions
[conda-badge]:              https://img.shields.io/conda/vn/conda-forge/coincident
[conda-link]:               https://github.com/conda-forge/coincident-feedstock
[github-discussions-badge]: https://img.shields.io/static/v1?label=Discussions&message=Ask&color=blue&logo=github
[github-discussions-link]:  https://github.com/uw-cryo/coincident/discussions
[pypi-link]:                https://pypi.org/project/coincident/
[pypi-platforms]:           https://img.shields.io/pypi/pyversions/coincident
[pypi-version]:             https://img.shields.io/pypi/v/coincident
[rtd-badge]:                https://readthedocs.org/projects/coincident/badge/?version=latest
[rtd-link]:                 https://coincident.readthedocs.io/en/latest/?badge=latest

<!-- prettier-ignore-end -->

Identify, curate, process and distribute coincident datasets contained within
select archives across a range of representative terrain and landcover types.
Such datasets are intended to be used by the NASA STV community for
calibration/validation, fusion algorithm development, and discipline-specific
scientific analysis.

See here for more information:
<https://science.nasa.gov/earth-science/decadal-surveys/decadal-stv/coincident-datasets>

## Acknowledgements

- Python packaging template provided by
  <https://github.com/scientific-python/cookie>

- Funding for this effort was provided by NASA Grant 80NSSC22K1094
